# Constraint

The Constraint commands define constraints between regions of the model.

## Create constraints

```{eval-rst}
.. autoclass:: abaqus.Constraint.ConstraintModel.ConstraintModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.Constraint.Constraint.Constraint
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Constraint.AdjustPoints.AdjustPoints
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::


    .. autoclass:: abaqus.Constraint.Coupling.Coupling
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Constraint.DisplayBody.DisplayBody
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Constraint.EmbeddedRegion.EmbeddedRegion
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Constraint.Equation.Equation
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Constraint.MultipointConstraint.MultipointConstraint
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Constraint.RigidBody.RigidBody
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Constraint.ShellSolidCoupling.ShellSolidCoupling
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.Constraint.Tie.Tie
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
